%  POLYVAL Evaluate Polynomial Fit at Selected Points
%  
%  
%  USAGE
%  
%  The polyval routine has the following syntax
%  
%    y = polyval(p,x)
%  
%  where p is a vector of polynomial coefficients,
%  in decreasing degree (as generated by polyfit, for example).
%  If x is a matrix, the polynomial is evaluated in the matrix
%  sense (in which case x must be square).
%  
%  The polynomial is evaluated using a recursion method.  If the
%  polynomial is
%  
%  $
%     p(x) = p_1 x^n + p_2 x^{n-1} + \dots + p_n x + p_{n+1}
%  $
%  
%  then the calculation is performed as
%  
%  $
%     p(x) = ((p_1) x + p_2) x + p_3
%  $
%  
%  
function y = polyval(p,x)
y = p(1);
n = prod(size(p));
for i = 2:n
  y = y.*x + p(i);
end
